==> phylogemetric-0.9.5.tar.gz: phylogemetric-0.9.5/setup.py <==
#!/usr/bin/env python
from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='phylogemetric',
    version='0.9.5',
    description='A python library for calculating the delta score (Holland et al. 2002) and Q-Residual (Gray et al. 2010)',
    long_description=long_description,
    url='https://github.com/SimonGreenhill/phylogemetric',
    author='Simon J. Greenhill',
    author_email='simon@simon.net.nz',
    license='BSD',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: BSD License",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        "Topic :: Software Development :: Libraries :: Python Modules",
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    keywords='phylogenetics delta-score q-residual',
    packages=find_packages(),
    install_requires=['nose', 'python-nexus'],
    #scripts=['phylogemetric/bin/phylogemetric.py'],
    entry_points={
       'console_scripts': ['phylogemetric=phylogemetric.bin.phylogemetric:main'],
    },
    test_suite = 'nose.collector',
)

==> phylogemetric-1.0rc1.tar.gz: phylogemetric-1.0rc1/setup.py <==
#!/usr/bin/env python
from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='phylogemetric',
    version='1.0rc1',
    description='A python library for calculating the delta score (Holland et al. 2002) and Q-Residual (Gray et al. 2010)',
    long_description=long_description,
    url='https://github.com/SimonGreenhill/phylogemetric',
    author='Simon J. Greenhill',
    author_email='simon@simon.net.nz',
    license='BSD',
    zip_safe=True,
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: BSD License",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        "Topic :: Software Development :: Libraries :: Python Modules",
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    keywords='phylogenetics delta-score q-residual',
    packages=find_packages(),
    install_requires=['python-nexus'],
    entry_points={
       'console_scripts': [
           'phylogemetric = phylogemetric.bin.phylogemetric:main'
       ],
    },
    test_suite = 'nose.collector',
)
